@@ -31,7 +31,7 @@
 #include <stdlib.h>
 #include <sys/time.h>
 
-#include <gdk/gdkwindow.h>
+#include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
